pub enum GovernanceMonitorError {
MissingAttestation,
InvalidAttestation {
signer_did: Did,
},
FindingsDigestEncodingFailed {
reason: String,
},
AttestationMessageEncodingFailed {
reason: String,
},
FindingsDigestMismatch {
signer_did: Did,
},
CircuitBreakerTripped {
critical_count: u64,
threshold: u64,
},
HumanApprovalRequired {
run_id: String,
},
ApproverNotHuman,
}Expand description
Errors from governance monitor validation.
Variants
MissingAttestation
Attestation signature is missing.
InvalidAttestation
Attestation signature is invalid.
FindingsDigestEncodingFailed
Findings payload could not be canonically encoded for digesting.
AttestationMessageEncodingFailed
Attestation signature message could not be canonically encoded.
FindingsDigestMismatch
Attested digest does not match the actual findings payload.
CircuitBreakerTripped
Circuit breaker has been tripped — too many Critical findings.
Fields
HumanApprovalRequired
Self-improvement trigger requires human approval.
ApproverNotHuman
The approver is not a human DID (SignerType prefix != 0x01).