pub struct QuorumEvidence {
pub threshold: u32,
pub votes: Vec<QuorumVote>,
}Expand description
Quorum decision evidence.
Fields
threshold: u32votes: Vec<QuorumVote>Implementations
Sourceimpl QuorumEvidence
impl QuorumEvidence
Sourcepub fn is_met(&self) -> bool
pub fn is_met(&self) -> bool
Returns true if the raw approval count (all votes, regardless of
provenance) meets the threshold. Used for legacy/simple quorum checks.
Sourcepub fn is_met_authentic(&self) -> bool
pub fn is_met_authentic(&self) -> bool
Returns true if the threshold is met counting only non-synthetic
approved votes with explicit human, independent, first-order provenance.
Missing, system, synthetic, coordinated, or derivative provenance is
excluded from the human count per CR-001 8.3.
Sourcepub fn synthetic_vote_count(&self) -> usize
pub fn synthetic_vote_count(&self) -> usize
Count of votes where provenance explicitly marks the voter as synthetic.
Sourcepub fn duplicate_voters(&self) -> BTreeSet<Did>
pub fn duplicate_voters(&self) -> BTreeSet<Did>
Voter DIDs that appear more than once in the evidence.
Sourcepub fn distinct_approved_voter_count(&self) -> usize
pub fn distinct_approved_voter_count(&self) -> usize
Count distinct approved voter DIDs, regardless of provenance.
Sourcepub fn distinct_authentic_approved_voter_count(&self) -> usize
pub fn distinct_authentic_approved_voter_count(&self) -> usize
Count distinct approved voter DIDs that are not synthetic.